@@ -42,7 +42,7 @@
 using namespace Attica;
 
 ProjectTest::ProjectTest() : QMainWindow(),
-    m_mainWidget(0)
+    m_mainWidget(nullptr)
 {
     m_mainWidget = new QWidget();
     setCentralWidget(m_mainWidget);
@@ -51,20 +51,20 @@ ProjectTest::ProjectTest() : QMainWindow(),
     m_editor->setupUi(m_mainWidget);
 
     // Project page
-    connect(m_editor->save, SIGNAL(clicked()), this, SLOT(save()));
+    connect(m_editor->save, &QAbstractButton::clicked, this, &ProjectTest::save);
     connect(m_editor->create, SIGNAL(clicked()), this, SLOT(create()));
     connect(m_editor->deleteProject, SIGNAL(clicked()), this, SLOT(deleteProject()));
 
     // build service / job page
-    connect(m_editor->build, SIGNAL(clicked()), this, SLOT(createBuildServiceJob()));
-    connect(m_editor->cancelJob, SIGNAL(clicked()), this, SLOT(cancelBuildServiceJob()));
-    connect(m_editor->updateJob, SIGNAL(clicked()), this, SLOT(updateCurrentProject()));
-    connect(m_editor->buildServices, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)),
-            this, SLOT(selectedBuildServiceChanged(QListWidgetItem*,QListWidgetItem*)));
+    connect(m_editor->build, &QAbstractButton::clicked, this, &ProjectTest::createBuildServiceJob);
+    connect(m_editor->cancelJob, &QAbstractButton::clicked, this, &ProjectTest::cancelBuildServiceJob);
+    connect(m_editor->updateJob, &QAbstractButton::clicked, this, &ProjectTest::updateCurrentProject);
+    connect(m_editor->buildServices, &QListWidget::currentItemChanged,
+            this, &ProjectTest::selectedBuildServiceChanged);
 
     QAction *a = new QAction(this);
     a->setText(QLatin1String("Quit"));
-    connect(a, SIGNAL(triggered()), SLOT(close()));
+    connect(a, &QAction::triggered, this, &QWidget::close);
     menuBar()->addMenu(QLatin1String("File"))->addAction(a);
 
     initOcs();
@@ -76,7 +76,7 @@ ProjectTest::~ProjectTest()
 void ProjectTest::initOcs()
 {
     m_pm.setAuthenticationSuppressed(true);
-    connect(&m_pm, SIGNAL(providerAdded(Attica::Provider)), SLOT(providerAdded(Attica::Provider)));
+    connect(&m_pm, &ProviderManager::providerAdded, this, &ProjectTest::providerAdded);
     m_pm.loadDefaultProviders();
     m_mainWidget->setEnabled(false);
     setStatus(QLatin1String("Loading providers..."));
@@ -108,7 +108,7 @@ void ProjectTest::providerAdded(const Attica::Provider &provider)
 void ProjectTest::getProject(QString id)
 {
     ItemJob<Project> *job = m_provider.requestProject(id);
-    connect(job, SIGNAL(finished(Attica::BaseJob*)), SLOT(projectResult(Attica::BaseJob*)));
+    connect(job, &BaseJob::finished, this, &ProjectTest::projectResult);
     job->start();
     setStatus(QString(QLatin1String("Loading project %")).arg(id));
     m_mainWidget->setEnabled(false);
@@ -118,21 +118,21 @@ void ProjectTest::getProject(QString id)
 void ProjectTest::listProjects()
 {
     ListJob<Project> *job = m_provider.requestProjects();
-    connect(job, SIGNAL(finished(Attica::BaseJob*)), SLOT(projectListResult(Attica::BaseJob*)));
+    connect(job, &BaseJob::finished, this, &ProjectTest::projectListResult);
     job->start();
 }
 
 void ProjectTest::listBuildServices()
 {
     ListJob<BuildService> *job = m_provider.requestBuildServices();
-    connect(job, SIGNAL(finished(Attica::BaseJob*)), SLOT(buildServiceListResult(Attica::BaseJob*)));
+    connect(job, &BaseJob::finished, this, &ProjectTest::buildServiceListResult);
     job->start();
 }
 
 void ProjectTest::listBuildServiceJobs(const Project &p)
 {
     ListJob<BuildServiceJob> *job = m_provider.requestBuildServiceJobs(p);
-    connect(job, SIGNAL(finished(Attica::BaseJob*)), SLOT(buildServiceJobListResult(Attica::BaseJob*)));
+    connect(job, &BaseJob::finished, this, &ProjectTest::buildServiceJobListResult);
     job->start();
 }
 
@@ -183,9 +183,9 @@ Project ProjectTest::uiToProject()
     project.setVersion(m_editor->version->text());
     project.setLicense(m_editor->license->text());
     project.setUrl(m_editor->url->text());
-    QStringList _d = m_editor->developers->text().split(QLatin1Char(','));
+    const QStringList _d = m_editor->developers->text().split(QLatin1Char(','));
     QStringList devs;
-    foreach (const QString &dev, _d) {
+    for (const QString &dev : _d) {
         devs << dev.trimmed();
     }
     project.setDevelopers(devs);
@@ -200,7 +200,7 @@ Project ProjectTest::uiToProject()
 void ProjectTest::save()
 {
     Attica::PostJob *postjob = m_provider.editProject(uiToProject());
-    connect(postjob, SIGNAL(finished(Attica::BaseJob*)), SLOT(saveProjectResult(Attica::BaseJob*)));
+    connect(postjob, &BaseJob::finished, this, &ProjectTest::saveProjectResult);
     postjob->start();
     m_mainWidget->setEnabled(false);
 }
@@ -208,7 +208,7 @@ void ProjectTest::save()
 void ProjectTest::create()
 {
     Attica::PostJob *postjob = m_provider.createProject(uiToProject());
-    connect(postjob, SIGNAL(finished(Attica::BaseJob*)), SLOT(createProjectResult(Attica::BaseJob*)));
+    connect(postjob, &BaseJob::finished, this, &ProjectTest::createProjectResult);
     postjob->start();
     m_mainWidget->setEnabled(false);
 }
@@ -216,7 +216,7 @@ void ProjectTest::create()
 void ProjectTest::deleteProject()
 {
     Attica::PostJob *postjob = m_provider.deleteProject(uiToProject());
-    connect(postjob, SIGNAL(finished(Attica::BaseJob*)), SLOT(deleteProjectResult(Attica::BaseJob*)));
+    connect(postjob, &BaseJob::finished, this, &ProjectTest::deleteProjectResult);
     postjob->start();
     m_mainWidget->setEnabled(false);
 }
@@ -293,7 +293,8 @@ void ProjectTest::projectListResult(Attica::BaseJob *j)
         qDebug() << "Yay, no errors ...";
         QStringList projectIds;
 
-        foreach (const Project &p, listJob->itemList()) {
+        const auto itemList = listJob->itemList();
+        for (const Project &p : itemList) {
             m_projects[p.id()] = p;
             qDebug() << "New project:" << p.id() << p.name();
             output.append(QString(QLatin1String("<br />%1 (%2)")).arg(p.name(), p.id()));
@@ -301,7 +302,7 @@ void ProjectTest::projectListResult(Attica::BaseJob *j)
             m_editor->projects->insertItem(0, p.name(), p.id());
             // TODO: start project jobs here
         }
-        if (!listJob->itemList().count()) {
+        if (listJob->itemList().isEmpty()) {
             output.append(QLatin1String("No Projects found."));
         }
     } else if (j->metadata().error() == Metadata::OcsError) {
@@ -325,7 +326,8 @@ void ProjectTest::buildServiceListResult(Attica::BaseJob *j)
         Attica::ListJob<BuildService> *listJob = static_cast<Attica::ListJob<BuildService> *>(j);
         qDebug() << "Yay, no errors ...";
 
-        foreach (const BuildService &bs, listJob->itemList()) {
+        const auto itemList = listJob->itemList();
+        for (const BuildService &bs : itemList) {
             m_buildServices[bs.id()] = bs;
             qDebug() << "New OBS:" << bs.id() << bs.name() << bs.url();
             output.append(QString(QLatin1String("<br />%1 (%2) at %3")).arg(bs.name(), bs.id(), bs.url()));
@@ -337,7 +339,7 @@ void ProjectTest::buildServiceListResult(Attica::BaseJob *j)
             //new_bsa->setData(Qt::UserRole, QVariant(bs.id()));
 
         }
-        if (!listJob->itemList().count()) {
+        if (listJob->itemList().isEmpty()) {
             output.append(QLatin1String("No OBS'en found."));
         }
     } else if (j->metadata().error() == Metadata::OcsError) {
@@ -361,14 +363,15 @@ void ProjectTest::buildServiceJobListResult(Attica::BaseJob *j)
         Attica::ListJob<BuildServiceJob> *listJob = static_cast<Attica::ListJob<BuildServiceJob> *>(j);
         qDebug() << "Yay, no errors. Items found:" << listJob->itemList().count();
 
-        foreach (const BuildServiceJob &bsj, listJob->itemList()) {
+        const auto itemList = listJob->itemList();
+        for (const BuildServiceJob &bsj : itemList) {
             m_buildServiceJobs[bsj.id()] = bsj;
             qDebug() << "New BuildServiceJob:" << bsj.id() << bsj.name() << bsj.target();
             output.append(QString(QLatin1String("<br />%1 (%2) for %3")).arg(bsj.name(), bsj.id(), bsj.target()));
             QListWidgetItem *new_bsj = new QListWidgetItem(bsj.name(), m_editor->buildServiceJobs);
             new_bsj->setData(Qt::UserRole, QVariant(bsj.id()));
         }
-        if (!listJob->itemList().count()) {
+        if (listJob->itemList().isEmpty()) {
             output.append(QLatin1String("No jobs found."));
         }
     } else if (j->metadata().error() == Metadata::OcsError) {
@@ -384,11 +387,11 @@ void ProjectTest::buildServiceJobListResult(Attica::BaseJob *j)
 
 void ProjectTest::selectedBuildServiceChanged(QListWidgetItem *current, QListWidgetItem *previous)
 {
-
+    Q_UNUSED(previous)
     qDebug() << "current item changed to " << current->data(Qt::UserRole).toString();
     m_editor->targets->clear();
-    QList<Target> targetlist = m_buildServices[current->data(Qt::UserRole).toString()].targets();
-    foreach (const Target &t, targetlist) {
+    const QList<Target> targetlist = m_buildServices[current->data(Qt::UserRole).toString()].targets();
+    for (const Target &t : targetlist) {
         //m_editor->targets->insertItems(0, m_buildServices[current->data(Qt::UserRole).toString()].targets());
         m_editor->targets->insertItem(0, t.name, t.id);
         // FIXME: target id.
@@ -411,7 +414,7 @@ void ProjectTest::createBuildServiceJob()
     qDebug() << "Buildservice:" << b.buildServiceId();
     //*/
     Attica::PostJob *j = m_provider.createBuildServiceJob(b);
-    connect(j, SIGNAL(finished(Attica::BaseJob*)), this, SLOT(buildServiceJobCreated(Attica::BaseJob*)));
+    connect(j, &BaseJob::finished, this, &ProjectTest::buildServiceJobCreated);
     j->start();
     setStatus(QLatin1String("Starting a build job on the server."));
 }
@@ -423,7 +426,7 @@ void ProjectTest::cancelBuildServiceJob()
     BuildServiceJob b = BuildServiceJob();
     b.setId(bsj_id);
     Attica::PostJob *j = m_provider.cancelBuildServiceJob(b);
-    connect(j, SIGNAL(finished(Attica::BaseJob*)), this, SLOT(buildServiceJobCanceled(Attica::BaseJob*)));
+    connect(j, &BaseJob::finished, this, &ProjectTest::buildServiceJobCanceled);
     j->start();
 }
 
@@ -487,4 +490,3 @@ void ProjectTest::updateCurrentProject()
     listBuildServiceJobs(p);
 }
 
-#include "projecttest.moc"
